@@ -11,7 +11,7 @@ import debug
 import subprocess
 import os
 import uuid
-import quantumclient
+import neutronclient
 import fragment
 import yaml
 import json
